@@ -1,11 +1,11 @@
 
 #[cfg(unix)]
-pub fn reset_sigpipe() {
+pub fn reset() {
     unsafe {
         ::libc::signal(::libc::SIGPIPE, ::libc::SIG_DFL);
     }
 }
 
 #[cfg(not(unix))]
-pub fn reset_sigpipe() {
+pub fn reset() {
 }
\ No newline at end of file
